@@ -1,5 +1,6 @@
+from .svg_renderer.svg_renderer import SvgRenderer
 from .excel_renderer.excel_renderer import ExcelRenderer
 from .txt_renderer.console_renderer import ConsoleRenderer
 from .txt_renderer.txt_renderer import TxtRenderer
 
-__version__ = '0.2.6'
+__version__ = '0.9'
