@@ -1,3 +1,4 @@
+import tkinter
 from datetime import date, timedelta
 
 from linum.excel_renderer.base.style import Style
@@ -54,3 +55,18 @@ class ExcelRendererContext(Context):
 
     def dict(self) -> dict:
         return vars(self)
+
+
+class SvgRendererContext(Context):
+
+    def __init__(self, **kwargs):
+        self.styles = Style(".")
+
+        self.days_off = []
+        self.workdays = []
+
+        self.locale = None
+        self.width = tkinter.Tk().winfo_screenwidth()
+        self.css = None
+
+        super().__init__(**kwargs)
